pub struct NymNodeBond {
pub node_id: NodeId,
pub owner: String,
pub original_pledge: DecCoin,
pub bonding_height: u64,
pub is_unbonding: bool,
pub node: NymNode,
}Fields
node_id: NodeIdUnique id assigned to the bonded node.
owner: StringAddress of the owner of this nym-node.
original_pledge: DecCoinOriginal amount pledged by the operator of this node.
bonding_height: u64Block height at which this nym-node has been bonded.
is_unbonding: boolFlag to indicate whether this node is in the process of unbonding, that will conclude upon the epoch finishing.
node: NymNodeInformation provided by the operator for the purposes of bonding.
Implementations
Sourceimpl NymNodeBond
impl NymNodeBond
pub fn from_mixnet_contract_mixnode_bond( bond: MixnetContractNymNodeBond, reg: &RegisteredCoins, ) -> Result<NymNodeBond, TypesError>